\name{cv.search}
\alias{cv.search}

\title{Find bandwidth for kernel density estimate using least squares cross-validation}
\description{
Estimates the optimal bandwidth
of a kernel density estimate with spherical Gaussian kernel using least
squares cross-validation. The data should be sphered, i.e. have unit
covariance.
}

\usage{
cv.search(X, trial.par = c(0.05, 0.1, 0.15, 0.2, 0.3, 0.4, 0.6, 0.8, 1, 1.5, 2))
}
\arguments{
  \item{X}{data matrix. Rows correspond to observations, columns to
    variables. Data should be sphered.}
  \item{trial.par}{trial bandwidths}
}
\details{
  Function first evaluates least squares cross-validation criterion for
  all the bandwidths in trial.par. It then tries to find a bracket for
  the optimal bandwidth, i.e. a triple (b1 < b2 < b3) with CV(b1) >
  CV(b2) and CV(b3) > CV(b2). Finally, it uses golden section search to
  find a local minimum in the interval [b1, b3].
}
\value{
  \item{opt.smopar}{optimal bandwidth or NA is no bracket could be found}
  \item{smopars}{bandwidths in trial.par for which the value of the
    criterion was not NA}
  \item{cv}{values of the criterion for the bandwidths in smopar}
}
\references{B.W. Silverman. Density estimation for Statistics and Data
  Analysis. Chapman & Hall, 1986.}
\author{Werner Stuetzle}
\examples{
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
X.sphered <- sphere(X)

cv.search.out <- cv.search(X.sphered)
h <- cv.search.out$opt.smopar
h
## [1] 0.3510157
bandwidths.with.finite.cv <- cv.search.out$smopars
corresponding.values.of.cv <- cv.search.out$cv
plot(bandwidths.with.finite.cv, corresponding.values.of.cv, type = "l")
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}

