\name{gsl.all.gkl.diagnostic.plots}
\alias{gsl.all.gkl.diagnostic.plots}
\title{Draw diagnostic plots to judge separation between clusters}
\description{
  Visits all interior node of the cluster tree and draws the
  corresponding gkl diagnostic plot
}
\usage{
gsl.all.gkl.diagnostic.plots(X, gsl.cluster.out, tree.type =
  "cluster.tree", n.breaks = 20, ...)
}
\arguments{
  \item{X}{data matrix. Rows correspond to observations, columns to variables}
  \item{gsl.cluster.out}{output of gsl.cluster}
  \item{tree.type}{one of "cluster.tree" or "dendogram"}
  \item{n.breaks}{number of breaks in histograms}
  \item{\dots}{additional arguments passed on to gsl.draw.cluster.tree }
}
\value{none}

\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single
  Method for Estimating the Cluster Tree of a Density. Journal of
  Computational  and Graphical Statistics (to appear).}
\author{Werner Stuetzle}

\examples{
library(gslclust)
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
nn.mdsfun <- gsl.make.nn.mdsfun(X)
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun)
rs <- gsl.runt.size(gsl.cluster.out)
rs[1:10]
## [1] 50 38 16 14 14  7  5  4  4  4
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.threshold =
                               14)
gsl.all.gkl.diagnostic.plots(X, gsl.cluster.out)
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}
