\name{gsl.cluster}
\alias{gsl.cluster}
\title{Perform Generalized Single Linkage clustering}
\description{
Perform generalized single linkage clustering on a set of data and a
minimum density similarity function.
}
\usage{
gsl.cluster(X, mdsfun, pruning.criterion = "size", pruning.threshold =
            0, gsl.cluster.out = NULL, assign.fluff = T)
}
\arguments{
  \item{X}{
    data matrix. Rows correspond to observations, columns to variables
  }
  \item{mdsfun}{minimum density similarity function. A function of two
                variables 1 <= i, j <= nrow(X). For i != j, mdsfun(i, j) =
                minimum of estimated density along the line segment connecting
                observations i and j. For i == j, mdsfun(i, i) =
		estimated density for observation i.}
  \item{pruning.criterion}{one of "size" or "excess.mass".}
  \item{pruning.threshold}{lowest value of pruning criterion for which a split
                           is considered "significant".}
  \item{gsl.cluster.out}{result of previous call to gsl.cluster. In a typical analysis,
                         gsl.cluster will be called multiple times with different
                         pruning criteria or thresholds. Providing the result of a
                         previous call reduces computing time.}
  \item{assign.fluff}{determines whether or not fluff is assigned to clusters.
                      Assigning fluff can be time consuming for large cluster trees and
                      is unnecessary if the objective is to compute the values of the
                      pruning criterion.}
}
\value{
  An object describing the output of the clustering process. Not intended for public
  consumption.
}
\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single Method for
            Estimating the Cluster Tree of a Density. Journal of Computational
            and Graphical Statistics (to appear).}
\author{Werner Stuetzle }
\examples{
  library(gslclust)
  data(iris)
  attach(iris)
  X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
  nn.mdsfun <- gsl.make.nn.mdsfun(X)
  gsl.cluster.out <- gsl.cluster(X, nn.mdsfun)
  gsl.runt.size(gsl.cluster.out)[1:10]
  ## [1] 50 38 16 14 14  7  5  4  4  4
  gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.threshold = 14)
  obs.labels <- gsl.observation.labels(gsl.cluster.out)
  table(obs.labels, Species)
  ##        Species
  ##obs.labels setosa versicolor virginica
  ##      4      30          0         0
  ##      5      20          0         0
  ##      12      0         30         1
  ##      13      0         15         0
  ##      14      0          0        36
  ##      15      0          5        13
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}
