\name{gsl.cluster.tree}
\alias{gsl.cluster.tree}
\title{Access cluster tree}

\description{Returns the cluster tree}

\usage{
gsl.cluster.tree(gsl.cluster.out)
}
\arguments{
  \item{gsl.cluster.out}{output of function gsl.cluster}
}

\value{
  A matrix with 2*n.leaves - 1 rows and 6 columns. The columns are
  "leftson", "rightson", "runt.size", "runt.excess.mass", "leaf.code",
  "level". 
}
\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single
  Method for Estimating the Cluster Tree of a Density. Journal of
  Computational  and Graphical Statistics (to appear).}

\author{Werner Stuetzle}

\note{For leaves of the tree, the first four columns are 0. The leaf
  code of the root node is 1. The left daughter of a node with leaf code
  i has leaf code 2*i, the right daughter has leaf code 2*i + 1}

\examples{
library(gslclust)
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
nn.mdsfun <- gsl.make.nn.mdsfun(X)
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun)
rs <- gsl.runt.size(gsl.cluster.out)
rs[1:10]
## [1] 50 38 16 14 14  7  5  4  4  4
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.threshold =
                               38)
cluster.tree <- gsl.cluster.tree(gsl.cluster.out)
cluster.tree
##      leftson rightson runt.size runt.excess.mass leaf.code     level
## [1,]       2        3        50        0.3333333         1 0.0000000
## [2,]       0        0         0        0.0000000         2 0.6097108
## [3,]       4        5        38        0.2533333         3 0.6097108
## [4,]       0        0         0        0.0000000         6 2.4253563
## [5,]       0        0         0        0.0000000         7 2.4253563
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}

