\name{gsl.draw.cluster.tree}
\alias{gsl.draw.cluster.tree}
\title{Draw cluster tree }
\description{
Draws cluster tree. Leafs can be annotated with cluster numbers (between
1 and number of leaves) or leaf codes (see below). Internal nodes can be
annotated with runt size or runt excess mass (more precisely,
round(n*runt.excess.mass,0)).
}
\usage{
gsl.draw.cluster.tree(gsl.cluster.out, draw.cluster.numbers = F,
                      draw.cluster.leaf.codes = F,
                      draw.runt.excess.mass = F,
                      draw.runt.size = F)
}
\arguments{
  \item{gsl.cluster.out}{output of function gsl.cluster }
  \item{draw.cluster.numbers}{if T, annotate leaves with cluster
    numbers}
  \item{draw.cluster.leaf.codes}{if T, annotate leaves with cluster
    leaf codes}
  \item{draw.runt.excess.mass}{if T, annotate internal nodes with runt
    excess mass}
  \item{draw.runt.size}{if T, annotate internal nodes with runt size}  
}
\value{
  \item{x}{x-coordinates of nodes}
  \item{y}{y-coordinates of nodes}
  }
\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single Method for
            Estimating the Cluster Tree of a Density. Journal of Computational
            and Graphical Statistics (to appear).}
\author{Werner Stuetzle}
\note{Leaf codes are defined recursively. The root node of the cluster
  tree has leaf code 1. If a node has leaf code i, then the left
  daughter has leaf code 2*i and the right daughter has leaf code 2*i + 1.
}
\seealso{gsl.cluster}
\examples{
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
nn.mdsfun <- gsl.make.nn.mdsfun(X)
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, assign.fluff = FALSE)
rs <- gsl.runt.size(gsl.cluster.out)
rs[1:10]
##  [1] 50 38 16 14 14  7  5  4  4  4
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.criterion = "size",
                               pruning.threshold = 14)
gsl.dct.out <- gsl.draw.cluster.tree(gsl.cluster.out, draw.runt.size = TRUE,
                      draw.cluster.leaf.codes = TRUE)
gsl.dct.out
## $x
##  [1] -7.5 -9.0 -9.5 -8.5 -4.0 -5.5 -6.0 -5.0 -2.5 -3.0 -2.0
##
## $y
##  [1] 0.0000000 0.6097108 4.4721360 4.4721360 0.6097108 2.4253563 2.8867513
##  [8] 2.8867513 2.4253563 2.6726124 2.6726124




}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}

