\name{gsl.gkl.diagnostic.plot}
\alias{gsl.gkl.diagnostic.plot}
\title{Draw diagnostic plot to judge separation between high density clusters}
\description{
  Draws the cluster tree, and lets the user point at an internal node
  with the mouse. It then finds the observations in the cores of the
  left and right daughters of the node and computes the Fisher
  discriminant direction. It then produces two histograms. The upper
  histogram shows the projection of all the observations in the node on
  the discriminant direction. The lower histogram shows the projection
  of the core.
}
\usage{
gsl.gkl.diagnostic.plot(X, gsl.cluster.out, tree.type = "cluster.tree",
  n.breaks = 20, ...)
}
\arguments{
  \item{X}{data matrix. Rows correspond to observations, columns to variables}
  \item{gsl.cluster.out}{output of gsl.cluster}
  \item{tree.type}{one of "cluster.tree" or "dendogram"}
  \item{n.breaks}{number of breaks in histograms}
  \item{\dots}{additional arguments passed on to gsl.draw.cluster.tree }
}
\value{none}

\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single
  Method for Estimating the Cluster Tree of a Density. Journal of
  Computational  and Graphical Statistics (to appear).}
\author{Werner Stuetzle}

\examples{
library(gslclust)
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
nn.mdsfun <- gsl.make.nn.mdsfun(X)
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun)
rs <- gsl.runt.size(gsl.cluster.out)
rs[1:10]
## [1] 50 38 16 14 14  7  5  4  4  4
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.threshold = 14)
## gsl.gkl.diagnostic.plot(X, gsl.cluster.out)
## Execute previous line, click on root node and see clearly bimodal histogram
## gsl.gkl.diagnostic.plot(X, gsl.cluster.out)
## Excecute previous line, click on left daughter of root node and
## see separation that is much less clear
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}




