\name{gsl.observation.in.core}
\alias{gsl.observation.in.core}
\title{Assign observations to cluster core or fluff}

\description{Each observation is assigned to one of the high density
  clusters represented by the leaves of the cluster tree. The function
  gsl.observation.in.core returns a boolean vector in.core of length
  nobs, with in.core[i] == T if observation i is in the core of its
  leaf, and in.core[i] == F otherwise. 
}
\usage{
gsl.observation.in.core(gsl.cluster.out)
}
\arguments{
  \item{gsl.cluster.out}{Output of function gsl.cluster}
}

\value{
Boolean vector of length nobs with in.core[i] == T
  if observation i is in the core of the leaf, and in.core[i] == F
  otherwise. 
}
\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single
  Method for Estimating the Cluster Tree of a Density. Journal of
  Computational  and Graphical Statistics (to appear).}

\author{Werner Stuetzle}

\examples{
library(gslclust)
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
nn.mdsfun <- gsl.make.nn.mdsfun(X)
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun)
rs <- gsl.runt.size(gsl.cluster.out)
rs[1:10]
## [1] 50 38 16 14 14  7  5  4  4  4
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.threshold =
                               14)
obs.labels <- gsl.observation.labels(gsl.cluster.out)
table(obs.labels, Species)
##          Species
##obs.labels setosa versicolor virginica
##        4      30          0         0
##        5      20          0         0
##        12      0         30         1
##        13      0         15         0
##        14      0          0        36
##        15      0          5        13

in.core <- gsl.observation.in.core(gsl.cluster.out)
table(obs.labels[in.core], Species[in.core])
##      setosa versicolor virginica
##   4      16          0         0
##   5      16          0         0
##   12      0         22         0
##   13      0         14         0
##   14      0          0        21
##   15      0          3        11
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}

