\name{gsl.subtree.gkl.diagnostic.plot}
\alias{gsl.subtree.gkl.diagnostic.plot}
\title{Draw diagnostic plot to judge separation between high density clusters}
\description{
  Draws the cluster tree, and lets the user point at an internal node
  with the mouse. It then finds the leaves of the subtree rooted at the
  node, computes the two leading Fisher discriminant directions for
  the observations in the leaf cores, and projects the observations in
  the node on the Fisher plane.
}
\usage{
gsl.subtree.gkl.diagnostic.plot(X, gsl.cluster.out)
}
\arguments{
  \item{X}{data matrix. Rows correspond to observations, columns to variables}
  \item{gsl.cluster.out}{output of gsl.cluster}
}
\value{none}

\note{
  the function first shows the projection of the observations in the
  node on Fisher plane without indicating the correspondence between
  observations and leaves. Observations in leaf cores are drawn in
  black, fluff is drawn in grey. When the user hits "return" (or
  "enter") the leaves of the subtree and the corresponding observations
  are drawn in different colors. Observations in leaf cores are drawn as
  filled circles, fluff is drawn as small dots.
  
  If the subtree rooted at the selected node has only two leaves, then
  the function produces the standard gkl diagnostic plot.
  }
\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single
  Method for Estimating the Cluster Tree of a Density. Journal of
  Computational  and Graphical Statistics (to appear).}
\author{Werner Stuetzle}

\examples{
library(gslclust)
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
nn.mdsfun <- gsl.make.nn.mdsfun(X)
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun)
rs <- gsl.runt.size(gsl.cluster.out)
rs[1:10]
## [1] 50 38 16 14 14  7  5  4  4  4
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.threshold = 38)
## gsl.subtree.gkl.diagnostic.plot(X, gsl.cluster.out)
## Execute previous line, click on the root node and see that one
## leaf is clearly separated from the other two, which are not well
## separated.
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}

