\name{gsl.visually.select.observations.in.node}
\alias{gsl.visually.select.observations.in.node}
\title{Select observations in a node of the cluster tree}
\description{
  Draws the cluster tree, lets the user point at a node with the mouse,
  and returns the corresponding observations.
}
\usage{
gsl.visually.select.observations.in.node(gsl.cluster.out)
}
\arguments{
  \item{gsl.cluster.out}{output of gsl.cluster}
}
\value{
  \item{in.node}{vector of length nobs, with in.node[i] == T if
    observation i is in the node, and in.node[i] == F otherwise}
  \item{in.core}{vector of length nobs, with in.core[i] == T if
    observation i is in the core of the node, and in.node[i] == F if
    observation i is in the fluff}
}
\references{Stuetzle, W. and Nugent, R. (2009.) A Generalized Single
  Method for Estimating the Cluster Tree of a Density. Journal of
  Computational  and Graphical Statistics (to appear).}
\author{Werner Stuetzle}

\examples{
library(gslclust)
data(iris)
attach(iris)
X <- cbind(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
nn.mdsfun <- gsl.make.nn.mdsfun(X)
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun)
rs <- gsl.runt.size(gsl.cluster.out)
rs[1:10]
## [1] 50 38 16 14 14  7  5  4  4  4
gsl.cluster.out <- gsl.cluster(X, nn.mdsfun, pruning.threshold =
                               38)
## vsoin.out <- gsl.visually.select.observations.in.node(gsl.cluster.out)
## Execute previous line and click on node labeled "1"

## table(vsoin.out$in.node, Species)
##        Species
##         setosa versicolor virginica
##   FALSE      0         50        50
##   TRUE      50          0         0

## vsoin.out <- gsl.visually.select.observations.in.node(gsl.cluster.out)
## Execute previous line and click on node labeled "2"
## table(vsoin.out$in.node, Species)
##        Species
##         setosa versicolor virginica
##   FALSE     50          4        45
##   TRUE       0         46         5
## Leaf "2" contains 46 versicolor and 5 virginica

## table(vsoin.out$in.core, Species)
##        Species
##         setosa versicolor virginica
##   FALSE     50         11        50
##   TRUE       0         39         0
## The core of leaf "2" is pure - it contains 39 versicolor and
## 0 setosa and virginica
}
\keyword{nonparametric}
\keyword{multivariate}
\keyword{cluster}
